# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from .. import _utilities, _tables

__all__ = [
    'DeviceGroupDevice',
]

@pulumi.output_type
class DeviceGroupDevice(dict):
    def __init__(__self__, *,
                 name: Optional[str] = None,
                 set_sync_leader: Optional[bool] = None):
        """
        :param str name: Is the name of the device Group
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if set_sync_leader is not None:
            pulumi.set(__self__, "set_sync_leader", set_sync_leader)

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        Is the name of the device Group
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="setSyncLeader")
    def set_sync_leader(self) -> Optional[bool]:
        return pulumi.get(self, "set_sync_leader")

    def _translate_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop


