# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from .. import _utilities, _tables

__all__ = ['VirtualAddress']


class VirtualAddress(pulumi.CustomResource):
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 advertize_route: Optional[pulumi.Input[str]] = None,
                 arp: Optional[pulumi.Input[bool]] = None,
                 auto_delete: Optional[pulumi.Input[bool]] = None,
                 conn_limit: Optional[pulumi.Input[int]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 icmp_echo: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 traffic_group: Optional[pulumi.Input[str]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        `ltm.VirtualAddress` Configures Virtual Server

        For resources should be named with their "full path". The full path is the combination of the partition + name of the resource. For example /Common/my-pool.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        vs_va = f5bigip.ltm.VirtualAddress("vsVa",
            advertize_route="true",
            name="/Common/vs_va")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] advertize_route: Enabled dynamic routing of the address
        :param pulumi.Input[bool] arp: Enable or disable ARP for the virtual address
        :param pulumi.Input[bool] auto_delete: Automatically delete the virtual address with the virtual server
        :param pulumi.Input[int] conn_limit: Max number of connections for virtual address
        :param pulumi.Input[bool] enabled: Enable or disable the virtual address
        :param pulumi.Input[bool] icmp_echo: Enable/Disable ICMP response to the virtual address
        :param pulumi.Input[str] name: Name of the virtual address
        :param pulumi.Input[str] traffic_group: Specify the partition and traffic group
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['advertize_route'] = advertize_route
            __props__['arp'] = arp
            __props__['auto_delete'] = auto_delete
            __props__['conn_limit'] = conn_limit
            __props__['enabled'] = enabled
            __props__['icmp_echo'] = icmp_echo
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__['name'] = name
            __props__['traffic_group'] = traffic_group
        super(VirtualAddress, __self__).__init__(
            'f5bigip:ltm/virtualAddress:VirtualAddress',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            advertize_route: Optional[pulumi.Input[str]] = None,
            arp: Optional[pulumi.Input[bool]] = None,
            auto_delete: Optional[pulumi.Input[bool]] = None,
            conn_limit: Optional[pulumi.Input[int]] = None,
            enabled: Optional[pulumi.Input[bool]] = None,
            icmp_echo: Optional[pulumi.Input[bool]] = None,
            name: Optional[pulumi.Input[str]] = None,
            traffic_group: Optional[pulumi.Input[str]] = None) -> 'VirtualAddress':
        """
        Get an existing VirtualAddress resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] advertize_route: Enabled dynamic routing of the address
        :param pulumi.Input[bool] arp: Enable or disable ARP for the virtual address
        :param pulumi.Input[bool] auto_delete: Automatically delete the virtual address with the virtual server
        :param pulumi.Input[int] conn_limit: Max number of connections for virtual address
        :param pulumi.Input[bool] enabled: Enable or disable the virtual address
        :param pulumi.Input[bool] icmp_echo: Enable/Disable ICMP response to the virtual address
        :param pulumi.Input[str] name: Name of the virtual address
        :param pulumi.Input[str] traffic_group: Specify the partition and traffic group
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["advertize_route"] = advertize_route
        __props__["arp"] = arp
        __props__["auto_delete"] = auto_delete
        __props__["conn_limit"] = conn_limit
        __props__["enabled"] = enabled
        __props__["icmp_echo"] = icmp_echo
        __props__["name"] = name
        __props__["traffic_group"] = traffic_group
        return VirtualAddress(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="advertizeRoute")
    def advertize_route(self) -> pulumi.Output[Optional[str]]:
        """
        Enabled dynamic routing of the address
        """
        return pulumi.get(self, "advertize_route")

    @property
    @pulumi.getter
    def arp(self) -> pulumi.Output[Optional[bool]]:
        """
        Enable or disable ARP for the virtual address
        """
        return pulumi.get(self, "arp")

    @property
    @pulumi.getter(name="autoDelete")
    def auto_delete(self) -> pulumi.Output[Optional[bool]]:
        """
        Automatically delete the virtual address with the virtual server
        """
        return pulumi.get(self, "auto_delete")

    @property
    @pulumi.getter(name="connLimit")
    def conn_limit(self) -> pulumi.Output[Optional[int]]:
        """
        Max number of connections for virtual address
        """
        return pulumi.get(self, "conn_limit")

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        Enable or disable the virtual address
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="icmpEcho")
    def icmp_echo(self) -> pulumi.Output[Optional[bool]]:
        """
        Enable/Disable ICMP response to the virtual address
        """
        return pulumi.get(self, "icmp_echo")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the virtual address
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="trafficGroup")
    def traffic_group(self) -> pulumi.Output[Optional[str]]:
        """
        Specify the partition and traffic group
        """
        return pulumi.get(self, "traffic_group")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

